# Welcome to **3D** - the package for Python game design

3D is a project designed to make programming 3D games as easy as possible.  
3D gives developers an easy way to build great games and 3D renders using nothing but Python.

> **Note**: 3D is imported using `import g`, not `import 3d`!
